@@ -30,7 +30,11 @@ def dispatch(event, context):
         return handler(proto, context)
     except Exception as e:
         print("Unexpected exception:", str(e))
-        return {"ok": False, "error": str(e)}
+        return error_response(str(e))
+
+
+def error_response(message):
+    return {"OK": False, "error": message}
 
 
 def _get_handler(action):
